@@ -35,8 +35,8 @@ def module_state(state):
 
 def precache(transition_datas):
     for tran_datas in transition_datas:
-        tran_datas['question_natex'].precache()
-    parsed_trees = [x['question_natex']._compiler._parsed_tree for x in transition_datas]
+        tran_datas['natex'].precache()
+    parsed_trees = [x['natex']._compiler._parsed_tree for x in transition_datas]
     return parsed_trees
 
 _autostate = '-1'
@@ -546,7 +546,7 @@ class DialogueFlow:
         if process_num == 1:
             for transition in self._graph.arcs():
                 data = self._graph.arc_data(*transition)
-                data['question_natex'].precache()
+                data['natex'].precache()
         else:
             transition_data_sets = []
             for i in range(process_num):
@@ -565,7 +565,7 @@ class DialogueFlow:
                 for j in range(len(result_list)):
                     parsed_tree = result_list[j]
                     t = t_list[j]
-                    t['question_natex']._compiler._parsed_tree = parsed_tree
+                    t['natex']._compiler._parsed_tree = parsed_tree
 
 
     def check(self, debugging=False):
@@ -671,13 +671,13 @@ class DialogueFlow:
         source, target = module_source_target(source, target)
         source = State(source)
         target = State(target)
-        return self._graph.arc_data(source, target, speaker)['question_natex']
+        return self._graph.arc_data(source, target, speaker)['natex']
 
     def set_transition_natex(self, source, target, speaker, natex):
         source, target = module_source_target(source, target)
         source = State(source)
         target = State(target)
-        self._graph.arc_data(source, target, speaker)['question_natex'] = natex
+        self._graph.arc_data(source, target, speaker)['natex'] = natex
 
     def transition_settings(self, source: Union[Enum, str, tuple], target: Union[Enum, str, tuple], speaker: Enum):
         source, target = module_source_target(source, target)
