@@ -393,7 +393,7 @@ df.add_system_transition(State.MIS_TRANSPORT_FAIL, State.TRANS, '"That is a good
 
 ### (SYSTEM) RESPOND TO USER UNLIKELY
 df.add_system_transition(State.REC_TELEPORT_UNLIKELY, State.HARDEST_PART,
-                         ['[!#GATE(transport_fail) "We will just have to wait and see, I guess."]', '"Yeah, at this point, it is just fiction, after all."'])
+                         ['[!#GATE(hardest_part:None) "We will just have to wait and see, I guess."]', '"Yeah, at this point, it is just fiction, after all."'])
 df.add_system_transition(State.HARDEST_PART, State.REC_HARDEST_PART, '[! "I am curious to know. What do you think is the hardest part of actually making a teleportation device?" #SetTrue(hardest_part)]')
 df.update_state_settings(State.HARDEST_PART, system_multi_hop=True)
 construct_nlu = "{" \
