@@ -45,6 +45,7 @@ class State(Enum):
     U10 = auto()
     END = auto()
     ERR = auto()
+    STOP_AR = auto()
 
     S2_what_is_vr = auto()
     vr_unknown = auto()
@@ -203,16 +204,20 @@ df.add_system_transition(State.dont_remember_sick, State.U4, '"Hopefully you did
 ar_unknown = '{' \
                '[{[!{dont,do not}, know],not sure,unsure,uncertain}, what, {that,a r,ar,augmented,reality,it,you said}, {is,mean,means}],' \
                '[what,is,{that,it,a r,ar,augmented,reality,you said}],' \
-               '[what,does,{that,a r,ar,augmented,reality,it,you said},mean]' \
+               '[what,does,{that,a r,ar,augmented,reality,it,you said},mean],' \
+               '[#NOT(you),never,heard,{that,a r,ar,augmented,reality,it,you said}],' \
+               '[#NOT(you),have,no,idea,what,{that,a r,ar,augmented,reality,it,you said},{is,mean,means}]' \
                '}'
 df.add_user_transition(State.U4, State.S4_what_is_ar, ar_unknown, score=0.9)
-df.add_system_transition(State.S4_what_is_ar, State.U4, '"Yeah, not everyone knows of augmented reality devices. Augmented reality is a new technology '
+df.add_system_transition(State.S4_what_is_ar, State.U4, '[!#GATE() "Yeah, not everyone knows of augmented reality devices. Augmented reality is a new technology '
                                                         'that allows images to be placed on top of what you are looking at, to show either new objects or '
                                                         'some information about the environment. '
                                                         'This happens either using cameras in mobile applications or from wearing a pair of special glasses. '
-                                                        'So, what do you think of that technology?"')
+                                                        'So, what do you think of that technology?"]')
+df.add_system_transition(State.S4_what_is_ar, State.STOP_AR, '"Since you do not seem to know too much about it, I think we should talk about something else. "', score=0.0)
+df.update_state_settings(State.STOP_AR, system_multi_hop=True)
 
-df.add_user_transition(State.U4, State.dont_know_ar_reason, dont_know)
+df.add_user_transition(State.U4, State.dont_know_ar_reason, dont_know, score=0.8)
 df.add_system_transition(State.dont_know_ar_reason, State.U6, '"You don\'t have any ideas? That is ok. It is still a relatively new thing, so it may be hard '
                                                               'to form an opinion. If you were to play a mobile game using A R, what would make it the most fun, '
                                                               'do you think?"')
